;; Generated package description from dicom.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "dicom" "1.5.0.20260811.6" "DICOM viewer - Digital Imaging & Communications in Medicine" '((emacs "29.1") (compat "31")) :commit "2f89c3e94195a6e77822d2a85fc105717fd0cf2e" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("multimedia" "hypermedia" "files") :url "https://github.com/minad/dicom")
